@@ -5,12 +5,13 @@ import requests
 import os
 import string
 import random
+from typing import BinaryIO
 from uuid import UUID, uuid4
 from binascii import hexlify
 
-from samino.lib import *
-from samino.socket import Socket, Recall
-from samino.lib import CheckExceptions
+from .lib import *
+from .socket import Socket, Recall
+from .lib import CheckExceptions
 
 
 class Client(Recall, Socket):
@@ -24,6 +25,7 @@ class Client(Recall, Socket):
         self.headers = headers.Headers().headers
         self.ad_headers = headers.AdHeaders().headers
         self.ad_data = headers.AdHeaders().data
+        self.web_headers = headers.Headers().web_headers
         Recall.__init__(self)
         Socket.__init__(self, self)
 
@@ -50,13 +52,11 @@ class Client(Recall, Socket):
             self.uid = uid
         self.sid = f"sid={sid}"
         headers.sid = self.sid
-        if self.uid:
-            headers.uid = self.uid
-        else:
-            headers.uid = " "
+        if self.uid: headers.uid = self.uid
+        else: headers.uid = " "
 
-    def login(self, email: str, password: str, isWeb: bool = True):
-        if isWeb:
+    def login(self, email: str, password: str, asWeb: bool = True):
+        if asWeb:
             data = {
                 "auth_type": 0,
                 "email": email,
@@ -65,17 +65,18 @@ class Client(Recall, Socket):
                 "secret": password
             }
             req = requests.post("https://aminoapps.com/api/auth", json=data)
-            if req.status_code != 200: return CheckExceptions(req.json())
-            self.sid = req.headers["set-cookie"]
             try:
-                self.sid = self.sid[0: self.sid.index(";")]
+                self.web_headers = req.headers
+                self.sid = req.headers["set-cookie"]
+                try: self.sid = self.sid[0: self.sid.index(";")]
+                except: self.sid = self.sid
+                self.uid = req.json()["result"]["uid"]
+                self.headers["NDCAUTH"] = self.sid
+                headers.uid = self.uid
+                headers.sid = self.sid
+                return Json(req.json())
             except:
-                self.sid = self.sid
-            self.uid = req.json()["result"]["uid"]
-            self.headers["NDCAUTH"] = self.sid
-            headers.sid = self.sid.replace("sid=", "")
-            headers.uid = self.uid
-            return Json(req.json())
+                return CheckExceptions(req.json())
 
         data = json.dumps({
             "email": email,
@@ -95,10 +96,24 @@ class Client(Recall, Socket):
         return Login(req.json())
 
     def logout(self):
+        self.web_headers = {"cookie": f"sid={self.sid.replace('sid=', '')}; Expires=Thu, 01-Jan-1970 00:00:00 GMT; Path=/"}
+        req = requests.post("https://aminoapps.com/api/logout", headers=self.web_headers)
         self.sid = None
         self.uid = None
-        self.headers["NDCAUTH"] = None
-        return True
+        self.headers.pop("NDCAUTH")
+        req.headers["cookie"] = req.headers["set-cookie"]
+        req.headers.pop("set-cookie")
+        self.web_headers = req.headers
+        return Json(req.json())
+
+    def upload_image(self, image: BinaryIO):
+        data = image.read()
+
+        self.headers["content-type"] = "image/jpg"
+        self.headers["content-length"] = str(len(data))
+
+        req = requests.post(f"{self.api}/g/s/media/upload", data=data, headers=self.headers)
+        return req.json()["mediaValue"]
 
     def send_verify_code(self, email: str):
         data = json.dumps({
@@ -172,6 +187,11 @@ class Client(Recall, Socket):
         if req.status_code != 200: return CheckExceptions(req.json())
         return MyChats(req.json()['threadList'])
 
+    def get_chat_info(self, chatId: str):
+        req = requests.get(f"{self.api}/g/s/chat/thread/{chatId}", headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return ChatInfo(req.json()['thread'])
+
     def leave_chat(self, chatId: str):
         req = requests.delete(f'{self.api}/g/s/chat/thread/{chatId}/member/{self.uid}', headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
@@ -490,7 +510,13 @@ class Client(Recall, Socket):
         if req.status_code != 200: return CheckExceptions(req.json())
         return WalletInfo(req.json()['wallet'])
 
-    def get_all_users(self, start: int = 0, size: int = 25):
+    def get_all_users(self, type: str = "recent", start: int = 0, size: int = 25):
+        if type == "recent": type = "recent"
+        elif type == "banned": type = "banned"
+        elif type == "featured": type = "featured"
+        elif type == "leaders": type = "leaders"
+        elif type == "curators": type = "curators"
+
         req = requests.get(f'{self.api}/g/s/user-profile?type=recent&start={start}&size={size}', headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserList(req.json()['userProfileList'])
