@@ -1,13 +1,15 @@
 import json
 import requests
+import websocket
 
 import os
+import threading
 from uuid import UUID
 from typing import BinaryIO
 from binascii import hexlify
 
-from samino.lib import *
-from samino.lib import CheckExceptions
+from .lib import *
+from .lib import CheckExceptions
 
 # Created By Bovonos -_-
 # Solved-Rewrited-Edited By SirLez too Many Times -_-
@@ -18,100 +20,112 @@ class Local:
         if comId is None: self.comId = None
         elif comId is not None: self.comId = comId
         self.uid = headers.Headers().uid
+        headers.comId = self.comId
         self.headers = headers.Headers().headers
-        self.web_headers = {
-            "cookie": f"{self.headers['NDCAUTH']}",
-            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.159 Safari/537.36",
-            "x-requested-with": "xmlhttprequest"
-        }
+        self.web_headers = headers.Headers().web_headers
         self.api = "https://service.narvii.com/api/v1"
+        websocket.enableTrace(False)
+        self.ws = websocket.WebSocket()
+        self.ws.connect("wss://ws1.narvii.com", header=self.headers)
+        data = {
+            "o": {
+                "actions": ["Browsing"],
+                "target": f"ndc://x{self.comId}/",
+                "ndcId": int(self.comId),
+                "id": "82333"
+            },
+            "t": 304
+        }
+        data = json.dumps(data)
+        try: threading.Thread(target=self.user_active_time).start()
+        except: pass
+        self.send(data)
 
-    # Not now kiddo ._.
+    def send(self, data): self.ws.send(data)
+    def close(self): self.ws.close()
 
-    #     def start_vc(self, chatId: str, joinType: int = 1):
-    #       data = {
-    #           "o": {
-    #               "ndcId": self.comId,
-    #               "threadId": chatId,
-    #               "joinRole": joinType,
-    #               "id": "2154531"
-    #           },
-    #           "t": 112
-    #       }
-    #       data = json.dumps(data)
-    #       self.send(data)
-    #       data = {
-    #           "o": {
-    #               "ndcId": self.comId,
-    #               "threadId": chatId,
-    #               "channelType": 1,
-    #               "id": "2154531"
-    #           },
-    #           "t": 108
-    #       }
-    #       data = json.dumps(data)
-    #       self.send(data)
-    #
-    #     def end_vc(self, chatId: str = None):
-    #       data = {
-    #           "o": {
-    #               "ndcId": self.comId,
-    #               "threadId": chatId,
-    #               "joinRole": 2,
-    #               "id": "2154531"
-    #           },
-    #           "t": 112
-    #       }
-    #       data = json.dumps(data)
-    #       self.send(data)
-    #       self.close()
-    #
-    def join_chat(self, chatId: str = None):
-        req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/{self.uid}", headers=self.headers)
-        if req.status_code != 200:
-            return CheckExceptions(req.json())
-        else:
+    def start_vc(self, chatId: str, joinType: int = 1):
+        data = {
+            "o": {
+                "ndcId": self.comId,
+                "threadId": chatId,
+                "joinRole": joinType,
+                "id": "2154531"
+            },
+            "t": 112
+        }
+        data = json.dumps(data)
+        self.send(data)
+        data = {
+            "o": {
+                "ndcId": self.comId,
+                "threadId": chatId,
+                "channelType": 1,
+                "id": "2154531"
+            },
+            "t": 108
+        }
+        data = json.dumps(data)
+        self.send(data)
+
+    # Not Working :(
+    # Solved in 1 hour -_-
+    def end_vc(self, chatId: str = None):
+        data = {
+            "o": {
+                "ndcId": self.comId,
+                "threadId": chatId,
+                "joinRole": 2,
+                "id": "2154531"
+            },
+            "t": 112
+        }
+        data = json.dumps(data)
+        self.send(data)
+        self.close()
+        self.ws.send_close()
+
+    def join_chat(self, chatId: str = None, asWeb: bool = False):
+        if asWeb:
+            data = {"ndcId": "x"+self.comId, "threadId": chatId}
+            req = requests.post("https://aminoapps.com/api/join-thread", json=data, headers=self.web_headers)
+            try:
+                if "OK" not in req.json()["result"]["api:message"]: return CheckExceptions(req.json())
+                else: Json(req.json())
+            except: return CheckExceptions(req.json())
             return Json(req.json())
 
+        req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/{self.uid}", headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return Json(req.json())
+
     def leave_chat(self, chatId: str = None):
         req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/{self.uid}", headers=self.headers)
-        if req.status_code != 200:
-            return CheckExceptions(req.json())
-        else:
-            return Json(req.json())
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return Json(req.json())
 
     def get_member_following(self, userId: str = None, start: int = 0, size: int = 25):
-        req = requests.get(f"{self.api}/x{self.comId}/s/user-profile/{userId}/joined?start={start}&size={size}",
-                           headers=self.headers)
-        if req.status_code != 200:
-            return CheckExceptions(req.json())
-        else:
-            return UserList(req.json()['userProfileList'])
+        req = requests.get(f"{self.api}/x{self.comId}/s/user-profile/{userId}/joined?start={start}&size={size}", headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return UserList(req.json()['userProfileList'])
 
     def get_member_followers(self, userId: str = None, start: int = 0, size: int = 25):
         req = requests.get(f"{self.api}/x{self.comId}/s/user-profile/{userId}/joined?start={start}&size={size}")
-        if req.status_code != 200:
-            return CheckExceptions(req.json())
-        else:
-            return UserList(req.json()['userProfileList'])
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return UserList(req.json()['userProfileList'])
 
     def get_chat_threads(self, start: int = 0, size: int = 25):
-        req = requests.get(f'{self.api}/x{self.comId}/s/chat/thread?type=joined-me&start={start}&size={size}',
-                           headers=self.headers)
-        if req.status_code != 200:
-            return CheckExceptions(req.json())
-        else:
-            return MyChats(req.json())
+        req = requests.get(f'{self.api}/x{self.comId}/s/chat/thread?type=joined-me&start={start}&size={size}', headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return MyChats(req.json()['threadList'])
 
     def get_member_visitors(self, userId: str, start: int = 0, size: int = 25):
-        req = requests.get(f'{self.api}/x{self.comId}/s/user-profile/{userId}/visitors?start={start}&size={size}',
-                           headers=self.headers)
+        req = requests.get(f'{self.api}/x{self.comId}/s/user-profile/{userId}/visitors?start={start}&size={size}', headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Visitors(req.json()['visitors'])
 
     def get_chat_messages(self, chatId: str, size: int = 25):
-        req = requests.get(f'{self.api}/x{self.comId}/s/chat/thread/{chatId}/message?v=2&pagingType=t&size={size}',
-                           headers=self.headers)
+        req = requests.get(f'{self.api}/x{self.comId}/s/chat/thread/{chatId}/message?v=2&pagingType=t&size={size}', headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return ChatMessages(req.json()['messageList'])
 
@@ -120,59 +134,69 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserInfo(req.json()['userProfile'])
 
-    def get_wall_comments(self, userId: str, sorting: str,
-                          start: int = 0, size: int = 25):
+    def get_wall_comments(self, userId: str, sorting: str, start: int = 0, size: int = 25):
         sorting = sorting.lower()
 
-        if sorting == "newest":
-            sorting = "newest"
-        elif sorting == "oldest":
-            sorting = "oldest"
-        elif sorting == "top":
-            sorting = "vote"
-        else:
-            raise TypeError("حط تايب يا حمار")  # Not me typed this its (a7rf)
+        if sorting == "newest": sorting = "newest"
+        elif sorting == "oldest": sorting = "oldest"
+        elif sorting == "top": sorting = "vote"
+        else: raise TypeError("حط تايب يا حمار")  # Not me typed this its (a7rf)
 
-        req = requests.get(
-            f"{self.api}/x{self.comId}/s/user-profile/{userId}/g-comment?sort={sorting}&start={start}&size={size}",
-            headers=self.headers)
+        req = requests.get(f"{self.api}/x{self.comId}/s/user-profile/{userId}/g-comment?sort={sorting}&start={start}&size={size}", headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Comment(req.json()['commentList'])
 
-    def get_all_users(self, start: int = 0, size: int = 25):
-        req = requests.get(f'{self.api}/x{self.comId}/s/user-profile?type=recent&start={start}&size={size}',
-                           headers=self.headers)
+    def get_all_users(self, type: str = "recent", start: int = 0, size: int = 25):
+        if type == "recent": type = "recent"
+        elif type == "banned": type = "banned"
+        elif type == "featured": type = "featured"
+        elif type == "leaders": type = "leaders"
+        elif type == "curators": type = "curators"
+
+        req = requests.get(f'{self.api}/x{self.comId}/s/user-profile?type={type}&start={start}&size={size}', headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserList(req.json()['userProfileList'])
 
     def get_chat_members(self, start: int = 0, size: int = 25, chatId: str = None):
-        req = requests.get(
-            f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member?start={start}&size={size}&type=default&cv=1.2",
-            headers=self.headers)
+        req = requests.get(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member?start={start}&size={size}&type=default&cv=1.2", headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserList(req.json()['memberList'])
 
+    def get_chat_info(self, chatId: str):
+        req = requests.get(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}", headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return ChatInfo(req.json()['thread'])
+
     def get_online_users(self, start: int = 0, size: int = 25):
-        req = requests.get(
-            f"{self.api}/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:online-members&start={start}&size={size}",
-            headers=self.headers)
+        req = requests.get(f"{self.api}/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:online-members&start={start}&size={size}", headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserList(req.json()['userProfileList'])
 
-    def send_message(self, chatId: str, message: str = None, messageType: int = 0, replyTo: str = None,
-                     mentionUserIds: list = None, embedId: str = None, embedType: int = None, embedLink: str = None,
-                     embedTitle: str = None, embedContent: str = None, isWeb: bool = False):
-        if isWeb:
+    def get_public_chats(self, type: str = "recommended", start: int = 0, size: int = 50):
+        req = requests.get(f'{self.api}/x{self.comId}/s/chat/thread?type=public-all&filterType={type}&start={start}&size={size}', headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return MyChats(req.json()['threadList'])
+
+    def send_message(self, chatId: str, message: str = None, messageType: int = 0, icon: str = None, comId: str = None, replyTo: str = None, mentionUserIds: list = None, embedId: str = None, embedType: int = None, embedLink: str = None, embedTitle: str = None, embedContent: str = None, asWeb: bool = False):
+        if comId: self.comId = comId
+        if asWeb:
             data = {
                 "ndcId": f"x{self.comId}",
                 "threadId": chatId,
-                "message": {"content": message, "mediaType": 0, "type": 0, "sendFailed": False, "clientRefId": 0}
+                "message": {"content": message, "mediaType": 0, "type": messageType, "sendFailed": False, "clientRefId": 0}
             }
+            if icon:
+                data["message"]["content"] = None
+                data["message"]["uploadId"] = 0
+                data["message"]["mediaType"] = 100
+                data["message"]["mediaValue"] = icon
+
             req = requests.post("https://aminoapps.com/api/add-chat-message", json=data, headers=self.web_headers)
-            if req.status_code != 200:
-                return CheckExceptions(req.json())
-            else:
-                return Json(req.json())
+            try:
+                if req.json()["code"] != 200: return CheckExceptions(req.json())
+                else: Json(req.json())
+            except: return CheckExceptions(req.json())
+            return Json(req.json())
 
         uids = []
         if mentionUserIds:
@@ -198,49 +222,63 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def unfollow(self, userId: str, isWeb: bool = False):
-        if isWeb:
+    def unfollow(self, userId: str, asWeb: bool = False):
+        if asWeb:
             data = {
                 "ndcId": f"x{self.comId}",
                 "followee_id": userId,
                 "follower_id": self.uid
             }
             req = requests.post("https://aminoapps.com/api/unfollow-user", json=data, headers=self.web_headers)
-            if req.status_code != 200: return CheckExceptions(req.json())
+            try:
+                if req.json()["code"] != 200: return CheckExceptions(req.json())
+                else: Json(req.json())
+            except: return CheckExceptions(req.json())
             return Json(req.json())
 
         req = requests.post(f"{self.api}/g/s/user-profile/{userId}/member/{self.uid}", headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def follow(self, userId: [str, list], isWeb: bool = False):
-        if isWeb:
+    def follow(self, userId: [str, list], asWeb: bool = False):
+        if asWeb:
             data = {
                 "ndcId": f"x{self.comId}",
                 "followee_id": userId
             }
             req = requests.post("https://aminoapps.com/api/follow-user", json=data, headers=self.web_headers)
-            if req.status_code != 200: return CheckExceptions(req.json())
+            try:
+                if req.json()["code"] != 200: return CheckExceptions(req.json())
+                else: Json(req.json())
+            except: return CheckExceptions(req.json())
             return Json(req.json())
 
         data = {}
 
         if isinstance(userId, str): api = f"{self.api}/x{self.comId}/s/user-profile/{userId}/member"
-        if isinstance(userId,
-                      list): api = f'{self.api}/x{self.comId}/s/user-profile/{self.uid}/joined'; data = json.dumps(
-            {"targetUidList": userId})
+        if isinstance(userId, list): api = f'{self.api}/x{self.comId}/s/user-profile/{self.uid}/joined'; data = json.dumps({"targetUidList": userId})
 
         req = requests.post(api, headers=self.headers, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def start_chat(self, userId: [str, list], title: str = None, message: str = None, content: str = None):
-        if isinstance(userId, str):
-            userIds = [userId]
-        elif isinstance(userId, list):
-            userIds = userId
-        else:
-            raise TypeError("")
+    def start_chat(self, userId: [str, list], title: str = None, message: str = None, content: str = None, type: int = 0, asWeb: bool = False):
+        if isinstance(userId, str): userIds = [userId]
+        elif isinstance(userId, list): userIds = userId
+        else: raise TypeError("")
+        if asWeb:
+            data = {
+                "ndcId": self.comId,
+                "inviteeUids": userIds,
+                "initialMessageContent": message,
+                "type": type
+            }
+            req = requests.post("https://aminoapps.com/api/create-chat-thread", json=data, headers=self.web_headers)
+            try:
+                if "OK" not in req.json()["result"]["api:message"]: return CheckExceptions(req.json())
+                else: Json(req.json())
+            except: return CheckExceptions(req.json())
+            return Json(req.json())
 
         data = json.dumps({
             "title": title,
@@ -366,17 +404,26 @@ class Local:
 
               - **Fail** : :meth:`Exceptions <samino.lib.exceptions>`
         """
-        if value != 1:
-            pass
-        elif value != -1:
-            raise TypeError(f"Please fill the value by (-1 or 1) not ({value})")
+        if value != 1: pass
+        elif value != -1: raise TypeError(f"Please fill the value by (-1 or 1) not ({value})")
         data = json.dumps({"value": value})
-        req = requests.post(f"{self.api}/x{self.comId}/s/blog/{blogId}/comment/{commentId}/vote?cv=1.2&value=1",
-                            data=data, headers=self.headers)
+        req = requests.post(f"{self.api}/x{self.comId}/s/blog/{blogId}/comment/{commentId}/vote?cv=1.2&value=1", data=data, headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def like_blog(self, blogId: str = None, wikiId: str = None):
+    def like_blog(self, blogId: str = None, wikiId: str = None, asWeb: bool = False):
+        if asWeb:
+            data = {"ndcId": self.comId}
+            if blogId: data["logType"] = "blog"; data["postType"] = "blog"; postId = blogId
+            if wikiId: data["logType"] = "wiki"; data["postType"] = "wiki"; postId = wikiId
+            data["postId"] = postId
+            req = requests.post("https://aminoapps.com/api/vote", json=data, headers=self.web_headers)
+            try:
+                if "OK" not in req.json()["result"]["api:message"]: return CheckExceptions(req.json())
+                else: Json(req.json())
+            except: return CheckExceptions(req.json())
+            return Json(req.json())
+
         data = json.dumps({"value": 4})
         if blogId: api = f"{self.api}/x{self.comId}/s/blog/{blogId}/vote?cv=1.2&value=4"
         if wikiId: api = f"{self.api}/x{self.comId}/s/item/{wikiId}/vote?cv=1.2&value=4"
@@ -384,7 +431,19 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def unlike_blog(self, blogId: str = None, wikiId: str = None):
+    def unlike_blog(self, blogId: str = None, wikiId: str = None, asWeb: bool = False):
+        if asWeb:
+            data = {"ndcId": self.comId, }
+            if blogId: data["logType"] = "blog"; data["postType"] = "blog"; postId = blogId
+            if wikiId: data["logType"] = "wiki"; data["postType"] = "wiki"; postId = wikiId
+            data["postId"] = postId
+            req = requests.post("https://aminoapps.com/api/unvote", json=data, headers=self.web_headers)
+            try:
+                if "OK" not in req.json()["result"]["api:message"]: return CheckExceptions(req.json())
+                else: Json(req.json())
+            except: return CheckExceptions(req.json())
+            return Json(req.json())
+
         if blogId: api = f"{self.api}/x{self.comId}/s/blog/{blogId}/vote?eventSource=FeedList"
         if wikiId: api = f"{self.api}/x{self.comId}/s/item/{wikiId}/vote?eventSource=FeedList"
         req = requests.delete(api, headers=self.headers)
@@ -419,14 +478,25 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def comment(self, comment: str, userId: str = None, blogId: str = None, wikiId: str = None, replyTo: str = None,
-                isGuest: bool = False):
+    def comment(self, comment: str, userId: str = None, blogId: str = None, wikiId: str = None, replyTo: str = None, isGuest: bool = False, asWeb: bool = False):
+        if asWeb:
+            data = {"ndcId": self.comId, "content": comment}
+            if blogId: data["postType"] = "blog"; postId = blogId
+            if wikiId: data["postType"] = "wiki"; postId = wikiId
+            if userId: data["postType"] = "user"; postId = userId
+            data["postId"] = postId
+
+            req = requests.post("https://aminoapps.com/api/submit_comment", json=data, headers=self.web_headers)
+            try:
+                if "data-comment-id" not in req.json()["result"]["html"]: return CheckExceptions(req.json())
+                else: Json(req.json())
+            except: return CheckExceptions(req.json())
+            return Json(req.json())
+
         data = {"content": comment}
         if replyTo: data["respondTo"] = replyTo
-        if isGuest:
-            comType = "g-comment"
-        else:
-            comType = "comment"
+        if isGuest: comType = "g-comment"
+        else: comType = "comment"
         if userId: api = f"{self.api}/x{self.comId}/s/user-profile/{userId}/{comType}"
         if blogId: api = f"{self.api}/x{self.comId}/s/blog/{blogId}/{comType}"
         if wikiId: api = f"{self.api}/x{self.comId}/s/item/{wikiId}/{comType}"
@@ -515,17 +585,32 @@ class Local:
         else:
             return Json(req.json())
 
-    def delete_message(self, chatId: str, messageId: str):
-        req = requests.delete(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/message/{messageId}", headers=self.headers)
-        if req.status_code != 200: return CheckExceptions(req.json())
-        return Json(req.json())
+    def delete_message(self, chatId: str, messageId: str, isStaff: bool = False, reason: str = None):
+        if isStaff:
+            data = {
+                "adminOpName": 102,
+                "adminOpNote": {"content": reason},
+            }
+            data["adminOpNote"] = {"content": reason}
+            data = json.dumps(data)
+            print(data)
+            req = requests.delete(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/message/{messageId}/admin", data=data, headers=self.headers)
+            print(req.json())
+            if req.status_code != 200: return CheckExceptions(req.json())
+            return Json(req.json())
+        else:
+            req = requests.delete(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/message/{messageId}", headers=self.headers)
+            if req.status_code != 200: return CheckExceptions(req.json())
+            return Json(req.json())
 
     def invite_by_host(self, chatId: str, userId: [str, list]):
         data = json.dumps({"uidList": userId})
         req = requests.post(url=f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/avchat-members", headers=self.headers,
                             data=data)
-        if req.status_code != 200: return CheckExceptions(req.json())
-        else: return Json(req.json())
+        if req.status_code != 200:
+            return CheckExceptions(req.json())
+        else:
+            return Json(req.json())
 
     def strike(self, userId: str, time: int, title: str = None, reason: str = None):
         data = json.dumps({
@@ -686,8 +771,7 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def subscribe(self, userId: str, autoRenew: str = False,
-                  transactionId: str = str(UUID(hexlify(os.urandom(16)).decode('ascii')))):
+    def subscribe(self, userId: str, autoRenew: str = False, transactionId: str = str(UUID(hexlify(os.urandom(16)).decode('ascii')))):
         data = json.dumps({
             "paymentContext": {
                 "transactionId": transactionId,
@@ -706,8 +790,7 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
-    def edit_blog(self, title: str, content: str, blogId: str = None, wikiId: str = None, fansOnly: bool = False,
-                  background: BinaryIO = None, backgroundColor: str = None):
+    def edit_blog(self, title: str, content: str, blogId: str = None, wikiId: str = None, fansOnly: bool = False, backgroundColor: str = None):
         data = {
             "title": title,
             "content": content
@@ -722,9 +805,7 @@ class Local:
         return Json(req.json())
 
     def get_chat_bubbles(self, start: int = 0, size: int = 20):
-        req = requests.get(
-            url=f"{self.api}/x{self.comId}/s/chat/chat-bubble?type=all-my-bubbles&start={start}&size={size}",
-            headers=self.headers)
+        req = requests.get(f"{self.api}/x{self.comId}/s/chat/chat-bubble?type=all-my-bubbles&start={start}&size={size}", headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return BubbleList(req.json()["chatBubbleList"])
 
@@ -760,3 +841,11 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
+    def user_active_time(self):
+        data = {"ndcId": self.comId}
+        req = requests.post("https://aminoapps.com/api/community/stats/web-user-active-time", json=data, headers=self.web_headers)
+        try:
+            if req.json()["code"] != 200: return CheckExceptions(req.json())
+            else: Json(req.json())
+        except: return CheckExceptions(req.json())
+        return Json(req.json())
